import 'dart:convert';

class DiscoveriesDataValue {
  final int newArtistsCount;
  final int newTracksCount;

  const DiscoveriesDataValue({required this.newArtistsCount, required this.newTracksCount});

  factory DiscoveriesDataValue.fromJson(Map<String, dynamic> json) {
    return DiscoveriesDataValue(
      newArtistsCount: json['new-artists'] as int,
      newTracksCount: json['new-tracks'] as int,
    );
  }
}

class DiscoveriesData {
  final Map<String, DiscoveriesDataValue> data;

  const DiscoveriesData({
    required this.data,
  });

  factory DiscoveriesData.fromJson(Map<String, dynamic> json) {
    Map<String, DiscoveriesDataValue> data = {};

    json.keys.forEach((date) {
      DiscoveriesDataValue value = DiscoveriesDataValue(
        newArtistsCount: json[date]['new-artists'] as int,
        newTracksCount: json[date]['new-tracks'] as int,
      );

      data[date] = value;
    });

    return DiscoveriesData(data: data);
  }

  factory DiscoveriesData.createEmpty() {
    return DiscoveriesData.fromJson({});
  }

  String toString() {
    Map<String, Map<String, int>> map = {};

    this.data.keys.forEach((element) {
      DiscoveriesDataValue? item = this.data[element];
      map[element] = {
        'new-artists': item != null ? item.newArtistsCount : 0,
        'new-tracks': item != null ? item.newTracksCount : 0,
      };
    });

    return jsonEncode(map);
  }
}
